==> zio-aws-detective_3-5.17.116.2-sources.jar: zio/aws/detective/model/ListOrganizationAdminAccountsRequest.scala <==
package zio.aws.detective.model
import java.lang.Integer
import zio.ZIO
import zio.aws.detective.model.primitives.{MemberResultsLimit, PaginationToken}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListOrganizationAdminAccountsRequest(
    nextToken: Option[PaginationToken] = None,
    maxResults: Option[MemberResultsLimit] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest = {
    import ListOrganizationAdminAccountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MemberResultsLimit.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly =
    zio.aws.detective.model.ListOrganizationAdminAccountsRequest
      .wrap(buildAwsValue())
}
object ListOrganizationAdminAccountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.detective.model.ListOrganizationAdminAccountsRequest =
      zio.aws.detective.model.ListOrganizationAdminAccountsRequest(
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def nextToken: Option[PaginationToken]
    def maxResults: Option[MemberResultsLimit]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MemberResultsLimit] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ) extends zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly {
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.detective.model.primitives.PaginationToken(value))
    override val maxResults: Option[MemberResultsLimit] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.detective.model.primitives.MemberResultsLimit(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ): zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-detective_3-5.17.257.1-sources.jar: zio/aws/detective/model/ListOrganizationAdminAccountsRequest.scala <==
package zio.aws.detective.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.detective.model.primitives.{MemberResultsLimit, PaginationToken}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListOrganizationAdminAccountsRequest(
    nextToken: Optional[PaginationToken] = Optional.Absent,
    maxResults: Optional[MemberResultsLimit] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest = {
    import ListOrganizationAdminAccountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => MemberResultsLimit.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly =
    zio.aws.detective.model.ListOrganizationAdminAccountsRequest
      .wrap(buildAwsValue())
}
object ListOrganizationAdminAccountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.detective.model.ListOrganizationAdminAccountsRequest =
      zio.aws.detective.model.ListOrganizationAdminAccountsRequest(
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def nextToken: Optional[PaginationToken]
    def maxResults: Optional[MemberResultsLimit]
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, MemberResultsLimit] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ) extends zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly {
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.detective.model.primitives.PaginationToken(value))
    override val maxResults: Optional[MemberResultsLimit] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.detective.model.primitives.MemberResultsLimit(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.detective.model.ListOrganizationAdminAccountsRequest
  ): zio.aws.detective.model.ListOrganizationAdminAccountsRequest.ReadOnly =
    new Wrapper(impl)
}
